@@ -1,5 +1,5 @@
 package Slackware::SBoKeeper::System;
-our $VERSION = '2.05';
+our $VERSION = '2.06';
 use 5.016;
 use strict;
 use warnings;
@@ -48,6 +48,14 @@ if ($IS_SLACKWARE) {
 		: '/var/lib/pkgtools/packages'
 	;
 
+	__PACKAGE__->load;
+
+}
+
+sub load {
+
+	%PACKAGES = ();
+
 	foreach my $pkgf (glob "$PKGTOOL_LOGS/*") {
 		$pkgf = basename($pkgf);
 		# Copied this regex from sbopkg
@@ -60,6 +68,8 @@ if ($IS_SLACKWARE) {
 		};
 	}
 
+	return 1;
+
 }
 
 sub is_slackware { $IS_SLACKWARE };
@@ -114,6 +124,12 @@ as methods of C<Slackware::SBoKeeper::System>.
 
 =over 4
 
+=item load()
+
+Loads the Slackware package database. Automatically called when the module is
+first loaded (if we're on a Slackware system). Can be be called again to reload
+the database.
+
 =item is_slackware()
 
 Returns true if we're on a Slackware system, false if we're not.
